@@ -80,7 +80,7 @@ class MSVCCompiler(distutils.msvccompiler.MSVCCompiler):
         if self.force or output_file is None or newer(source, output_file):
             try:
                 self.spawn(cpp_args)
-            except (DistutilsExecError, msg):
+            except DistutilsExecError as msg:
                 print(msg)
                 raise CompileError
 
